# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: autofs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='autofs.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0c\x61utofs.proto\"\x96\x01\n\x0c\x61utofs_entry\x12\n\n\x02\x66\x64\x18\x01 \x02(\x05\x12\x0c\n\x04pgrp\x18\x02 \x02(\x05\x12\x0f\n\x07timeout\x18\x03 \x02(\x05\x12\x10\n\x08minproto\x18\x04 \x02(\x05\x12\x10\n\x08maxproto\x18\x05 \x02(\x05\x12\x0c\n\x04mode\x18\x06 \x02(\x05\x12\x0b\n\x03uid\x18\x07 \x01(\x05\x12\x0b\n\x03gid\x18\x08 \x01(\x05\x12\x0f\n\x07read_fd\x18\t \x01(\x05')
)




_AUTOFS_ENTRY = _descriptor.Descriptor(
  name='autofs_entry',
  full_name='autofs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fd', full_name='autofs_entry.fd', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pgrp', full_name='autofs_entry.pgrp', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='autofs_entry.timeout', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minproto', full_name='autofs_entry.minproto', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxproto', full_name='autofs_entry.maxproto', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='autofs_entry.mode', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='autofs_entry.uid', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='autofs_entry.gid', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_fd', full_name='autofs_entry.read_fd', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17,
  serialized_end=167,
)

DESCRIPTOR.message_types_by_name['autofs_entry'] = _AUTOFS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

autofs_entry = _reflection.GeneratedProtocolMessageType('autofs_entry', (_message.Message,), dict(
  DESCRIPTOR = _AUTOFS_ENTRY,
  __module__ = 'autofs_pb2'
  # @@protoc_insertion_point(class_scope:autofs_entry)
  ))
_sym_db.RegisterMessage(autofs_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: netdev.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import macvlan_pb2 as macvlan__pb2
import opts_pb2 as opts__pb2
import tun_pb2 as tun__pb2
import sysctl_pb2 as sysctl__pb2
import sit_pb2 as sit__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='netdev.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0cnetdev.proto\x1a\rmacvlan.proto\x1a\nopts.proto\x1a\ttun.proto\x1a\x0csysctl.proto\x1a\tsit.proto\"\xdd\x02\n\x10net_device_entry\x12\x16\n\x04type\x18\x01 \x02(\x0e\x32\x08.nd_type\x12\x0f\n\x07ifindex\x18\x02 \x02(\r\x12\x0b\n\x03mtu\x18\x03 \x02(\r\x12\x14\n\x05\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04name\x18\x05 \x02(\t\x12\x1c\n\x03tun\x18\x06 \x01(\x0b\x32\x0f.tun_link_entry\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\x0c\x12\x0c\n\x04\x63onf\x18\x08 \x03(\x05\x12\x1c\n\x05\x63onf4\x18\t \x03(\x0b\x32\r.sysctl_entry\x12\x1c\n\x05\x63onf6\x18\n \x03(\x0b\x32\r.sysctl_entry\x12$\n\x07macvlan\x18\x0b \x01(\x0b\x32\x13.macvlan_link_entry\x12\x14\n\x0cpeer_ifindex\x18\x0c \x01(\r\x12\x11\n\tpeer_nsid\x18\r \x01(\r\x12\x0e\n\x06master\x18\x0e \x01(\r\x12\x17\n\x03sit\x18\x0f \x01(\x0b\x32\n.sit_entry\"7\n\x08netns_id\x12\x14\n\x0ctarget_ns_id\x18\x01 \x02(\r\x12\x15\n\rnetnsid_value\x18\x02 \x02(\x05\"\xe4\x01\n\x0bnetns_entry\x12\x10\n\x08\x64\x65\x66_conf\x18\x01 \x03(\x05\x12\x10\n\x08\x61ll_conf\x18\x02 \x03(\x05\x12 \n\tdef_conf4\x18\x03 \x03(\x0b\x32\r.sysctl_entry\x12 \n\tall_conf4\x18\x04 \x03(\x0b\x32\r.sysctl_entry\x12 \n\tdef_conf6\x18\x05 \x03(\x0b\x32\r.sysctl_entry\x12 \n\tall_conf6\x18\x06 \x03(\x0b\x32\r.sysctl_entry\x12\x18\n\x05nsids\x18\x07 \x03(\x0b\x32\t.netns_id\x12\x0f\n\x07\x65xt_key\x18\x08 \x01(\t*d\n\x07nd_type\x12\x0c\n\x08LOOPBACK\x10\x01\x12\x08\n\x04VETH\x10\x02\x12\x07\n\x03TUN\x10\x03\x12\x0b\n\x07\x45XTLINK\x10\x04\x12\t\n\x05VENET\x10\x05\x12\n\n\x06\x42RIDGE\x10\x06\x12\x0b\n\x07MACVLAN\x10\x07\x12\x07\n\x03SIT\x10\x08')
  ,
  dependencies=[macvlan__pb2.DESCRIPTOR,opts__pb2.DESCRIPTOR,tun__pb2.DESCRIPTOR,sysctl__pb2.DESCRIPTOR,sit__pb2.DESCRIPTOR,])

_ND_TYPE = _descriptor.EnumDescriptor(
  name='nd_type',
  full_name='nd_type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOOPBACK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VETH', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TUN', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTLINK', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VENET', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MACVLAN', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIT', index=7, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=719,
  serialized_end=819,
)
_sym_db.RegisterEnumDescriptor(_ND_TYPE)

nd_type = enum_type_wrapper.EnumTypeWrapper(_ND_TYPE)
LOOPBACK = 1
VETH = 2
TUN = 3
EXTLINK = 4
VENET = 5
BRIDGE = 6
MACVLAN = 7
SIT = 8



_NET_DEVICE_ENTRY = _descriptor.Descriptor(
  name='net_device_entry',
  full_name='net_device_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='net_device_entry.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ifindex', full_name='net_device_entry.ifindex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='net_device_entry.mtu', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='net_device_entry.flags', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='net_device_entry.name', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tun', full_name='net_device_entry.tun', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='net_device_entry.address', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conf', full_name='net_device_entry.conf', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conf4', full_name='net_device_entry.conf4', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conf6', full_name='net_device_entry.conf6', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macvlan', full_name='net_device_entry.macvlan', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_ifindex', full_name='net_device_entry.peer_ifindex', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_nsid', full_name='net_device_entry.peer_nsid', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master', full_name='net_device_entry.master', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sit', full_name='net_device_entry.sit', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=429,
)


_NETNS_ID = _descriptor.Descriptor(
  name='netns_id',
  full_name='netns_id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_ns_id', full_name='netns_id.target_ns_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='netnsid_value', full_name='netns_id.netnsid_value', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=486,
)


_NETNS_ENTRY = _descriptor.Descriptor(
  name='netns_entry',
  full_name='netns_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_conf', full_name='netns_entry.def_conf', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conf', full_name='netns_entry.all_conf', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='def_conf4', full_name='netns_entry.def_conf4', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conf4', full_name='netns_entry.all_conf4', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='def_conf6', full_name='netns_entry.def_conf6', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conf6', full_name='netns_entry.all_conf6', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nsids', full_name='netns_entry.nsids', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_key', full_name='netns_entry.ext_key', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=717,
)

_NET_DEVICE_ENTRY.fields_by_name['type'].enum_type = _ND_TYPE
_NET_DEVICE_ENTRY.fields_by_name['tun'].message_type = tun__pb2._TUN_LINK_ENTRY
_NET_DEVICE_ENTRY.fields_by_name['conf4'].message_type = sysctl__pb2._SYSCTL_ENTRY
_NET_DEVICE_ENTRY.fields_by_name['conf6'].message_type = sysctl__pb2._SYSCTL_ENTRY
_NET_DEVICE_ENTRY.fields_by_name['macvlan'].message_type = macvlan__pb2._MACVLAN_LINK_ENTRY
_NET_DEVICE_ENTRY.fields_by_name['sit'].message_type = sit__pb2._SIT_ENTRY
_NETNS_ENTRY.fields_by_name['def_conf4'].message_type = sysctl__pb2._SYSCTL_ENTRY
_NETNS_ENTRY.fields_by_name['all_conf4'].message_type = sysctl__pb2._SYSCTL_ENTRY
_NETNS_ENTRY.fields_by_name['def_conf6'].message_type = sysctl__pb2._SYSCTL_ENTRY
_NETNS_ENTRY.fields_by_name['all_conf6'].message_type = sysctl__pb2._SYSCTL_ENTRY
_NETNS_ENTRY.fields_by_name['nsids'].message_type = _NETNS_ID
DESCRIPTOR.message_types_by_name['net_device_entry'] = _NET_DEVICE_ENTRY
DESCRIPTOR.message_types_by_name['netns_id'] = _NETNS_ID
DESCRIPTOR.message_types_by_name['netns_entry'] = _NETNS_ENTRY
DESCRIPTOR.enum_types_by_name['nd_type'] = _ND_TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

net_device_entry = _reflection.GeneratedProtocolMessageType('net_device_entry', (_message.Message,), dict(
  DESCRIPTOR = _NET_DEVICE_ENTRY,
  __module__ = 'netdev_pb2'
  # @@protoc_insertion_point(class_scope:net_device_entry)
  ))
_sym_db.RegisterMessage(net_device_entry)

netns_id = _reflection.GeneratedProtocolMessageType('netns_id', (_message.Message,), dict(
  DESCRIPTOR = _NETNS_ID,
  __module__ = 'netdev_pb2'
  # @@protoc_insertion_point(class_scope:netns_id)
  ))
_sym_db.RegisterMessage(netns_id)

netns_entry = _reflection.GeneratedProtocolMessageType('netns_entry', (_message.Message,), dict(
  DESCRIPTOR = _NETNS_ENTRY,
  __module__ = 'netdev_pb2'
  # @@protoc_insertion_point(class_scope:netns_entry)
  ))
_sym_db.RegisterMessage(netns_entry)


_NET_DEVICE_ENTRY.fields_by_name['flags'].has_options = True
_NET_DEVICE_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: seccomp.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='seccomp.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rseccomp.proto\"=\n\x0eseccomp_filter\x12\x0e\n\x06\x66ilter\x18\x01 \x02(\x0c\x12\x0c\n\x04prev\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\"9\n\rseccomp_entry\x12(\n\x0fseccomp_filters\x18\x01 \x03(\x0b\x32\x0f.seccomp_filter')
)




_SECCOMP_FILTER = _descriptor.Descriptor(
  name='seccomp_filter',
  full_name='seccomp_filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='seccomp_filter.filter', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev', full_name='seccomp_filter.prev', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='seccomp_filter.flags', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17,
  serialized_end=78,
)


_SECCOMP_ENTRY = _descriptor.Descriptor(
  name='seccomp_entry',
  full_name='seccomp_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seccomp_filters', full_name='seccomp_entry.seccomp_filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=137,
)

_SECCOMP_ENTRY.fields_by_name['seccomp_filters'].message_type = _SECCOMP_FILTER
DESCRIPTOR.message_types_by_name['seccomp_filter'] = _SECCOMP_FILTER
DESCRIPTOR.message_types_by_name['seccomp_entry'] = _SECCOMP_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

seccomp_filter = _reflection.GeneratedProtocolMessageType('seccomp_filter', (_message.Message,), dict(
  DESCRIPTOR = _SECCOMP_FILTER,
  __module__ = 'seccomp_pb2'
  # @@protoc_insertion_point(class_scope:seccomp_filter)
  ))
_sym_db.RegisterMessage(seccomp_filter)

seccomp_entry = _reflection.GeneratedProtocolMessageType('seccomp_entry', (_message.Message,), dict(
  DESCRIPTOR = _SECCOMP_ENTRY,
  __module__ = 'seccomp_pb2'
  # @@protoc_insertion_point(class_scope:seccomp_entry)
  ))
_sym_db.RegisterMessage(seccomp_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsnotify.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fh_pb2 as fh__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsnotify.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0e\x66snotify.proto\x1a\nopts.proto\x1a\x08\x66h.proto\x1a\nfown.proto\"\x9e\x01\n\x10inotify_wd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05i_ino\x18\x02 \x02(\x04\x12\x13\n\x04mask\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cignored_mask\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x14\n\x05s_dev\x18\x05 \x02(\rB\x05\xd2?\x02 \x01\x12\n\n\x02wd\x18\x06 \x02(\r\x12\x1b\n\x08\x66_handle\x18\x07 \x02(\x0b\x32\t.fh_entry\"p\n\x12inotify_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x04 \x02(\x0b\x32\x0b.fown_entry\x12\x1d\n\x02wd\x18\x05 \x03(\x0b\x32\x11.inotify_wd_entry\"G\n\x19\x66\x61notify_inode_mark_entry\x12\r\n\x05i_ino\x18\x01 \x02(\x04\x12\x1b\n\x08\x66_handle\x18\x02 \x02(\x0b\x32\t.fh_entry\"9\n\x19\x66\x61notify_mount_mark_entry\x12\x0e\n\x06mnt_id\x18\x01 \x02(\r\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xea\x01\n\x13\x66\x61notify_mark_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x18\n\x04type\x18\x02 \x02(\x0e\x32\n.mark_type\x12\x15\n\x06mflags\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cignored_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x14\n\x05s_dev\x18\x06 \x02(\rB\x05\xd2?\x02 \x01\x12&\n\x02ie\x18\x07 \x01(\x0b\x32\x1a.fanotify_inode_mark_entry\x12&\n\x02me\x18\x08 \x01(\x0b\x32\x1a.fanotify_mount_mark_entry\"\xa6\x01\n\x13\x66\x61notify_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12\x16\n\x07\x66\x61\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x16\n\x07\x65vflags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\"\n\x04mark\x18\x06 \x03(\x0b\x32\x14.fanotify_mark_entry*!\n\tmark_type\x12\t\n\x05INODE\x10\x01\x12\t\n\x05MOUNT\x10\x02')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fh__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,])

_MARK_TYPE = _descriptor.EnumDescriptor(
  name='mark_type',
  full_name='mark_type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INODE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOUNT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=865,
  serialized_end=898,
)
_sym_db.RegisterEnumDescriptor(_MARK_TYPE)

mark_type = enum_type_wrapper.EnumTypeWrapper(_MARK_TYPE)
INODE = 1
MOUNT = 2



_INOTIFY_WD_ENTRY = _descriptor.Descriptor(
  name='inotify_wd_entry',
  full_name='inotify_wd_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='inotify_wd_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_ino', full_name='inotify_wd_entry.i_ino', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='inotify_wd_entry.mask', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignored_mask', full_name='inotify_wd_entry.ignored_mask', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='s_dev', full_name='inotify_wd_entry.s_dev', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wd', full_name='inotify_wd_entry.wd', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='f_handle', full_name='inotify_wd_entry.f_handle', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=211,
)


_INOTIFY_FILE_ENTRY = _descriptor.Descriptor(
  name='inotify_file_entry',
  full_name='inotify_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='inotify_file_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='inotify_file_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='inotify_file_entry.fown', index=2,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wd', full_name='inotify_file_entry.wd', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=325,
)


_FANOTIFY_INODE_MARK_ENTRY = _descriptor.Descriptor(
  name='fanotify_inode_mark_entry',
  full_name='fanotify_inode_mark_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='i_ino', full_name='fanotify_inode_mark_entry.i_ino', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='f_handle', full_name='fanotify_inode_mark_entry.f_handle', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=398,
)


_FANOTIFY_MOUNT_MARK_ENTRY = _descriptor.Descriptor(
  name='fanotify_mount_mark_entry',
  full_name='fanotify_mount_mark_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mnt_id', full_name='fanotify_mount_mark_entry.mnt_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='fanotify_mount_mark_entry.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=457,
)


_FANOTIFY_MARK_ENTRY = _descriptor.Descriptor(
  name='fanotify_mark_entry',
  full_name='fanotify_mark_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='fanotify_mark_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='fanotify_mark_entry.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mflags', full_name='fanotify_mark_entry.mflags', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='fanotify_mark_entry.mask', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignored_mask', full_name='fanotify_mark_entry.ignored_mask', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='s_dev', full_name='fanotify_mark_entry.s_dev', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ie', full_name='fanotify_mark_entry.ie', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='me', full_name='fanotify_mark_entry.me', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=694,
)


_FANOTIFY_FILE_ENTRY = _descriptor.Descriptor(
  name='fanotify_file_entry',
  full_name='fanotify_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='fanotify_file_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='fanotify_file_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='fanotify_file_entry.fown', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faflags', full_name='fanotify_file_entry.faflags', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evflags', full_name='fanotify_file_entry.evflags', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mark', full_name='fanotify_file_entry.mark', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=863,
)

_INOTIFY_WD_ENTRY.fields_by_name['f_handle'].message_type = fh__pb2._FH_ENTRY
_INOTIFY_FILE_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_INOTIFY_FILE_ENTRY.fields_by_name['wd'].message_type = _INOTIFY_WD_ENTRY
_FANOTIFY_INODE_MARK_ENTRY.fields_by_name['f_handle'].message_type = fh__pb2._FH_ENTRY
_FANOTIFY_MARK_ENTRY.fields_by_name['type'].enum_type = _MARK_TYPE
_FANOTIFY_MARK_ENTRY.fields_by_name['ie'].message_type = _FANOTIFY_INODE_MARK_ENTRY
_FANOTIFY_MARK_ENTRY.fields_by_name['me'].message_type = _FANOTIFY_MOUNT_MARK_ENTRY
_FANOTIFY_FILE_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_FANOTIFY_FILE_ENTRY.fields_by_name['mark'].message_type = _FANOTIFY_MARK_ENTRY
DESCRIPTOR.message_types_by_name['inotify_wd_entry'] = _INOTIFY_WD_ENTRY
DESCRIPTOR.message_types_by_name['inotify_file_entry'] = _INOTIFY_FILE_ENTRY
DESCRIPTOR.message_types_by_name['fanotify_inode_mark_entry'] = _FANOTIFY_INODE_MARK_ENTRY
DESCRIPTOR.message_types_by_name['fanotify_mount_mark_entry'] = _FANOTIFY_MOUNT_MARK_ENTRY
DESCRIPTOR.message_types_by_name['fanotify_mark_entry'] = _FANOTIFY_MARK_ENTRY
DESCRIPTOR.message_types_by_name['fanotify_file_entry'] = _FANOTIFY_FILE_ENTRY
DESCRIPTOR.enum_types_by_name['mark_type'] = _MARK_TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

inotify_wd_entry = _reflection.GeneratedProtocolMessageType('inotify_wd_entry', (_message.Message,), dict(
  DESCRIPTOR = _INOTIFY_WD_ENTRY,
  __module__ = 'fsnotify_pb2'
  # @@protoc_insertion_point(class_scope:inotify_wd_entry)
  ))
_sym_db.RegisterMessage(inotify_wd_entry)

inotify_file_entry = _reflection.GeneratedProtocolMessageType('inotify_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _INOTIFY_FILE_ENTRY,
  __module__ = 'fsnotify_pb2'
  # @@protoc_insertion_point(class_scope:inotify_file_entry)
  ))
_sym_db.RegisterMessage(inotify_file_entry)

fanotify_inode_mark_entry = _reflection.GeneratedProtocolMessageType('fanotify_inode_mark_entry', (_message.Message,), dict(
  DESCRIPTOR = _FANOTIFY_INODE_MARK_ENTRY,
  __module__ = 'fsnotify_pb2'
  # @@protoc_insertion_point(class_scope:fanotify_inode_mark_entry)
  ))
_sym_db.RegisterMessage(fanotify_inode_mark_entry)

fanotify_mount_mark_entry = _reflection.GeneratedProtocolMessageType('fanotify_mount_mark_entry', (_message.Message,), dict(
  DESCRIPTOR = _FANOTIFY_MOUNT_MARK_ENTRY,
  __module__ = 'fsnotify_pb2'
  # @@protoc_insertion_point(class_scope:fanotify_mount_mark_entry)
  ))
_sym_db.RegisterMessage(fanotify_mount_mark_entry)

fanotify_mark_entry = _reflection.GeneratedProtocolMessageType('fanotify_mark_entry', (_message.Message,), dict(
  DESCRIPTOR = _FANOTIFY_MARK_ENTRY,
  __module__ = 'fsnotify_pb2'
  # @@protoc_insertion_point(class_scope:fanotify_mark_entry)
  ))
_sym_db.RegisterMessage(fanotify_mark_entry)

fanotify_file_entry = _reflection.GeneratedProtocolMessageType('fanotify_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _FANOTIFY_FILE_ENTRY,
  __module__ = 'fsnotify_pb2'
  # @@protoc_insertion_point(class_scope:fanotify_file_entry)
  ))
_sym_db.RegisterMessage(fanotify_file_entry)


_INOTIFY_WD_ENTRY.fields_by_name['mask'].has_options = True
_INOTIFY_WD_ENTRY.fields_by_name['mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_INOTIFY_WD_ENTRY.fields_by_name['ignored_mask'].has_options = True
_INOTIFY_WD_ENTRY.fields_by_name['ignored_mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_INOTIFY_WD_ENTRY.fields_by_name['s_dev'].has_options = True
_INOTIFY_WD_ENTRY.fields_by_name['s_dev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001'))
_INOTIFY_FILE_ENTRY.fields_by_name['flags'].has_options = True
_INOTIFY_FILE_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_FANOTIFY_MARK_ENTRY.fields_by_name['mflags'].has_options = True
_FANOTIFY_MARK_ENTRY.fields_by_name['mflags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_FANOTIFY_MARK_ENTRY.fields_by_name['mask'].has_options = True
_FANOTIFY_MARK_ENTRY.fields_by_name['mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_FANOTIFY_MARK_ENTRY.fields_by_name['ignored_mask'].has_options = True
_FANOTIFY_MARK_ENTRY.fields_by_name['ignored_mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_FANOTIFY_MARK_ENTRY.fields_by_name['s_dev'].has_options = True
_FANOTIFY_MARK_ENTRY.fields_by_name['s_dev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001'))
_FANOTIFY_FILE_ENTRY.fields_by_name['flags'].has_options = True
_FANOTIFY_FILE_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_FANOTIFY_FILE_ENTRY.fields_by_name['faflags'].has_options = True
_FANOTIFY_FILE_ENTRY.fields_by_name['faflags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_FANOTIFY_FILE_ENTRY.fields_by_name['evflags'].has_options = True
_FANOTIFY_FILE_ENTRY.fields_by_name['evflags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipe-data.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pipe-data.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0fpipe-data.proto\"?\n\x0fpipe_data_entry\x12\x0f\n\x07pipe_id\x18\x01 \x02(\r\x12\r\n\x05\x62ytes\x18\x02 \x02(\r\x12\x0c\n\x04size\x18\x03 \x01(\r')
)




_PIPE_DATA_ENTRY = _descriptor.Descriptor(
  name='pipe_data_entry',
  full_name='pipe_data_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipe_id', full_name='pipe_data_entry.pipe_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='pipe_data_entry.bytes', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='pipe_data_entry.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['pipe_data_entry'] = _PIPE_DATA_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

pipe_data_entry = _reflection.GeneratedProtocolMessageType('pipe_data_entry', (_message.Message,), dict(
  DESCRIPTOR = _PIPE_DATA_ENTRY,
  __module__ = 'pipe_data_pb2'
  # @@protoc_insertion_point(class_scope:pipe_data_entry)
  ))
_sym_db.RegisterMessage(pipe_data_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: userns.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='userns.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0cuserns.proto\"C\n\x0euid_gid_extent\x12\r\n\x05\x66irst\x18\x01 \x02(\r\x12\x13\n\x0blower_first\x18\x02 \x02(\r\x12\r\n\x05\x63ount\x18\x03 \x02(\r\"R\n\x0cuserns_entry\x12 \n\x07uid_map\x18\x01 \x03(\x0b\x32\x0f.uid_gid_extent\x12 \n\x07gid_map\x18\x02 \x03(\x0b\x32\x0f.uid_gid_extent')
)




_UID_GID_EXTENT = _descriptor.Descriptor(
  name='uid_gid_extent',
  full_name='uid_gid_extent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='uid_gid_extent.first', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lower_first', full_name='uid_gid_extent.lower_first', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='uid_gid_extent.count', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=83,
)


_USERNS_ENTRY = _descriptor.Descriptor(
  name='userns_entry',
  full_name='userns_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid_map', full_name='userns_entry.uid_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid_map', full_name='userns_entry.gid_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=167,
)

_USERNS_ENTRY.fields_by_name['uid_map'].message_type = _UID_GID_EXTENT
_USERNS_ENTRY.fields_by_name['gid_map'].message_type = _UID_GID_EXTENT
DESCRIPTOR.message_types_by_name['uid_gid_extent'] = _UID_GID_EXTENT
DESCRIPTOR.message_types_by_name['userns_entry'] = _USERNS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

uid_gid_extent = _reflection.GeneratedProtocolMessageType('uid_gid_extent', (_message.Message,), dict(
  DESCRIPTOR = _UID_GID_EXTENT,
  __module__ = 'userns_pb2'
  # @@protoc_insertion_point(class_scope:uid_gid_extent)
  ))
_sym_db.RegisterMessage(uid_gid_extent)

userns_entry = _reflection.GeneratedProtocolMessageType('userns_entry', (_message.Message,), dict(
  DESCRIPTOR = _USERNS_ENTRY,
  __module__ = 'userns_pb2'
  # @@protoc_insertion_point(class_scope:userns_entry)
  ))
_sym_db.RegisterMessage(userns_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lve.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='lve.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tlve.proto\"]\n\x12lve_task_ids_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06\x63ookie\x18\x02 \x02(\r\x12\r\n\x05\x66lags\x18\x03 \x02(\r\x12\x0e\n\x06leader\x18\x04 \x02(\x08\x12\x0c\n\x04jail\x18\x05 \x02(\x08\"\xa0\x01\n\x12lve_settings_entry\x12\x0b\n\x03\x63pu\x18\x01 \x02(\x05\x12\x0c\n\x04\x63pus\x18\x02 \x02(\x05\x12\n\n\x02io\x18\x03 \x02(\x05\x12\x0e\n\x06\x65nters\x18\x04 \x02(\x05\x12\x0e\n\x06memory\x18\x05 \x02(\x05\x12\x12\n\ncpu_weight\x18\x06 \x02(\x05\x12\x12\n\nmemory_phy\x18\x07 \x02(\x05\x12\r\n\x05nproc\x18\x08 \x02(\x05\x12\x0c\n\x04iops\x18\t \x02(\x05\"H\n\tlve_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12 \n\x03set\x18\x03 \x02(\x0b\x32\x13.lve_settings_entry')
)




_LVE_TASK_IDS_ENTRY = _descriptor.Descriptor(
  name='lve_task_ids_entry',
  full_name='lve_task_ids_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='lve_task_ids_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='lve_task_ids_entry.cookie', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='lve_task_ids_entry.flags', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leader', full_name='lve_task_ids_entry.leader', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jail', full_name='lve_task_ids_entry.jail', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=106,
)


_LVE_SETTINGS_ENTRY = _descriptor.Descriptor(
  name='lve_settings_entry',
  full_name='lve_settings_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='lve_settings_entry.cpu', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpus', full_name='lve_settings_entry.cpus', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='io', full_name='lve_settings_entry.io', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enters', full_name='lve_settings_entry.enters', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory', full_name='lve_settings_entry.memory', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_weight', full_name='lve_settings_entry.cpu_weight', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory_phy', full_name='lve_settings_entry.memory_phy', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nproc', full_name='lve_settings_entry.nproc', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iops', full_name='lve_settings_entry.iops', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=269,
)


_LVE_ENTRY = _descriptor.Descriptor(
  name='lve_entry',
  full_name='lve_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='lve_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='lve_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set', full_name='lve_entry.set', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=343,
)

_LVE_ENTRY.fields_by_name['set'].message_type = _LVE_SETTINGS_ENTRY
DESCRIPTOR.message_types_by_name['lve_task_ids_entry'] = _LVE_TASK_IDS_ENTRY
DESCRIPTOR.message_types_by_name['lve_settings_entry'] = _LVE_SETTINGS_ENTRY
DESCRIPTOR.message_types_by_name['lve_entry'] = _LVE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

lve_task_ids_entry = _reflection.GeneratedProtocolMessageType('lve_task_ids_entry', (_message.Message,), dict(
  DESCRIPTOR = _LVE_TASK_IDS_ENTRY,
  __module__ = 'lve_pb2'
  # @@protoc_insertion_point(class_scope:lve_task_ids_entry)
  ))
_sym_db.RegisterMessage(lve_task_ids_entry)

lve_settings_entry = _reflection.GeneratedProtocolMessageType('lve_settings_entry', (_message.Message,), dict(
  DESCRIPTOR = _LVE_SETTINGS_ENTRY,
  __module__ = 'lve_pb2'
  # @@protoc_insertion_point(class_scope:lve_settings_entry)
  ))
_sym_db.RegisterMessage(lve_settings_entry)

lve_entry = _reflection.GeneratedProtocolMessageType('lve_entry', (_message.Message,), dict(
  DESCRIPTOR = _LVE_ENTRY,
  __module__ = 'lve_pb2'
  # @@protoc_insertion_point(class_scope:lve_entry)
  ))
_sym_db.RegisterMessage(lve_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-inet.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-inet.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rsk-inet.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\"^\n\x11ip_opts_raw_entry\x12\x0f\n\x07hdrincl\x18\x01 \x01(\x08\x12\x10\n\x08nodefrag\x18\x02 \x01(\x08\x12\x10\n\x08\x63hecksum\x18\x03 \x01(\x08\x12\x14\n\x0cicmpv_filter\x18\x04 \x03(\r\"B\n\rip_opts_entry\x12\x10\n\x08\x66reebind\x18\x01 \x01(\x08\x12\x1f\n\x03raw\x18\x04 \x01(\x0b\x32\x12.ip_opts_raw_entry\"\xae\x03\n\rinet_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x17\n\x06\x66\x61mily\x18\x03 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x15\n\x04type\x18\x04 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05proto\x18\x05 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05state\x18\x06 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x10\n\x08src_port\x18\x07 \x02(\r\x12\x10\n\x08\x64st_port\x18\x08 \x02(\r\x12\x14\n\x05\x66lags\x18\t \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x62\x61\x63klog\x18\n \x02(\r\x12\x17\n\x08src_addr\x18\x0b \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x08\x64st_addr\x18\x0c \x03(\rB\x05\xd2?\x02\x10\x01\x12\x19\n\x04\x66own\x18\r \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0e \x02(\x0b\x32\x0e.sk_opts_entry\x12\x0e\n\x06v6only\x18\x0f \x01(\x08\x12\x1f\n\x07ip_opts\x18\x10 \x01(\x0b\x32\x0e.ip_opts_entry\x12\x0e\n\x06ifname\x18\x11 \x01(\t\x12\r\n\x05ns_id\x18\x12 \x01(\r\x12\x1e\n\x08shutdown\x18\x13 \x01(\x0e\x32\x0c.sk_shutdown')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,sk__opts__pb2.DESCRIPTOR,])




_IP_OPTS_RAW_ENTRY = _descriptor.Descriptor(
  name='ip_opts_raw_entry',
  full_name='ip_opts_raw_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hdrincl', full_name='ip_opts_raw_entry.hdrincl', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodefrag', full_name='ip_opts_raw_entry.nodefrag', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='ip_opts_raw_entry.checksum', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icmpv_filter', full_name='ip_opts_raw_entry.icmpv_filter', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=150,
)


_IP_OPTS_ENTRY = _descriptor.Descriptor(
  name='ip_opts_entry',
  full_name='ip_opts_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='freebind', full_name='ip_opts_entry.freebind', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw', full_name='ip_opts_entry.raw', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=218,
)


_INET_SK_ENTRY = _descriptor.Descriptor(
  name='inet_sk_entry',
  full_name='inet_sk_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='inet_sk_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ino', full_name='inet_sk_entry.ino', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='family', full_name='inet_sk_entry.family', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='inet_sk_entry.type', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proto', full_name='inet_sk_entry.proto', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='inet_sk_entry.state', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_port', full_name='inet_sk_entry.src_port', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='inet_sk_entry.dst_port', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='inet_sk_entry.flags', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backlog', full_name='inet_sk_entry.backlog', index=9,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_addr', full_name='inet_sk_entry.src_addr', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_addr', full_name='inet_sk_entry.dst_addr', index=11,
      number=12, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='inet_sk_entry.fown', index=12,
      number=13, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='inet_sk_entry.opts', index=13,
      number=14, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='v6only', full_name='inet_sk_entry.v6only', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_opts', full_name='inet_sk_entry.ip_opts', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ifname', full_name='inet_sk_entry.ifname', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='inet_sk_entry.ns_id', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutdown', full_name='inet_sk_entry.shutdown', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=651,
)

_IP_OPTS_ENTRY.fields_by_name['raw'].message_type = _IP_OPTS_RAW_ENTRY
_INET_SK_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_INET_SK_ENTRY.fields_by_name['opts'].message_type = sk__opts__pb2._SK_OPTS_ENTRY
_INET_SK_ENTRY.fields_by_name['ip_opts'].message_type = _IP_OPTS_ENTRY
_INET_SK_ENTRY.fields_by_name['shutdown'].enum_type = sk__opts__pb2._SK_SHUTDOWN
DESCRIPTOR.message_types_by_name['ip_opts_raw_entry'] = _IP_OPTS_RAW_ENTRY
DESCRIPTOR.message_types_by_name['ip_opts_entry'] = _IP_OPTS_ENTRY
DESCRIPTOR.message_types_by_name['inet_sk_entry'] = _INET_SK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ip_opts_raw_entry = _reflection.GeneratedProtocolMessageType('ip_opts_raw_entry', (_message.Message,), dict(
  DESCRIPTOR = _IP_OPTS_RAW_ENTRY,
  __module__ = 'sk_inet_pb2'
  # @@protoc_insertion_point(class_scope:ip_opts_raw_entry)
  ))
_sym_db.RegisterMessage(ip_opts_raw_entry)

ip_opts_entry = _reflection.GeneratedProtocolMessageType('ip_opts_entry', (_message.Message,), dict(
  DESCRIPTOR = _IP_OPTS_ENTRY,
  __module__ = 'sk_inet_pb2'
  # @@protoc_insertion_point(class_scope:ip_opts_entry)
  ))
_sym_db.RegisterMessage(ip_opts_entry)

inet_sk_entry = _reflection.GeneratedProtocolMessageType('inet_sk_entry', (_message.Message,), dict(
  DESCRIPTOR = _INET_SK_ENTRY,
  __module__ = 'sk_inet_pb2'
  # @@protoc_insertion_point(class_scope:inet_sk_entry)
  ))
_sym_db.RegisterMessage(inet_sk_entry)


_INET_SK_ENTRY.fields_by_name['family'].has_options = True
_INET_SK_ENTRY.fields_by_name['family']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk'))
_INET_SK_ENTRY.fields_by_name['type'].has_options = True
_INET_SK_ENTRY.fields_by_name['type']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk'))
_INET_SK_ENTRY.fields_by_name['proto'].has_options = True
_INET_SK_ENTRY.fields_by_name['proto']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk'))
_INET_SK_ENTRY.fields_by_name['state'].has_options = True
_INET_SK_ENTRY.fields_by_name['state']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk'))
_INET_SK_ENTRY.fields_by_name['flags'].has_options = True
_INET_SK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_INET_SK_ENTRY.fields_by_name['src_addr'].has_options = True
_INET_SK_ENTRY.fields_by_name['src_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_INET_SK_ENTRY.fields_by_name['dst_addr'].has_options = True
_INET_SK_ENTRY.fields_by_name['dst_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pstree.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import lve_pb2 as lve__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pstree.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0cpstree.proto\x1a\tlve.proto\"w\n\x0cpstree_entry\x12\x0b\n\x03pid\x18\x01 \x02(\r\x12\x0c\n\x04ppid\x18\x02 \x02(\r\x12\x0c\n\x04pgid\x18\x03 \x02(\r\x12\x0b\n\x03sid\x18\x04 \x02(\r\x12\x0f\n\x07threads\x18\x05 \x03(\r\x12 \n\x03lve\x18\x06 \x01(\x0b\x32\x13.lve_task_ids_entry')
  ,
  dependencies=[lve__pb2.DESCRIPTOR,])




_PSTREE_ENTRY = _descriptor.Descriptor(
  name='pstree_entry',
  full_name='pstree_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='pstree_entry.pid', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ppid', full_name='pstree_entry.ppid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pgid', full_name='pstree_entry.pgid', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sid', full_name='pstree_entry.sid', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threads', full_name='pstree_entry.threads', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lve', full_name='pstree_entry.lve', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=146,
)

_PSTREE_ENTRY.fields_by_name['lve'].message_type = lve__pb2._LVE_TASK_IDS_ENTRY
DESCRIPTOR.message_types_by_name['pstree_entry'] = _PSTREE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

pstree_entry = _reflection.GeneratedProtocolMessageType('pstree_entry', (_message.Message,), dict(
  DESCRIPTOR = _PSTREE_ENTRY,
  __module__ = 'pstree_pb2'
  # @@protoc_insertion_point(class_scope:pstree_entry)
  ))
_sym_db.RegisterMessage(pstree_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opts.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opts.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\nopts.proto\x1a google/protobuf/descriptor.proto\"m\n\tCRIU_Opts\x12\x0b\n\x03hex\x18\x01 \x01(\x08\x12\r\n\x05ipadd\x18\x02 \x01(\x08\x12\r\n\x05\x66lags\x18\x03 \x01(\t\x12\x0b\n\x03\x64\x65v\x18\x04 \x01(\x08\x12\x0c\n\x04odev\x18\x05 \x01(\x08\x12\x0c\n\x04\x64ict\x18\x06 \x01(\t\x12\x0c\n\x04\x63onv\x18\x07 \x01(\t:8\n\x04\x63riu\x12\x1d.google.protobuf.FieldOptions\x18\xfa\x07 \x01(\x0b\x32\n.CRIU_Opts')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


CRIU_FIELD_NUMBER = 1018
criu = _descriptor.FieldDescriptor(
  name='criu', full_name='criu', index=0,
  number=1018, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None, file=DESCRIPTOR)


_CRIU_OPTS = _descriptor.Descriptor(
  name='CRIU_Opts',
  full_name='CRIU_Opts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hex', full_name='CRIU_Opts.hex', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipadd', full_name='CRIU_Opts.ipadd', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CRIU_Opts.flags', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dev', full_name='CRIU_Opts.dev', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='odev', full_name='CRIU_Opts.odev', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dict', full_name='CRIU_Opts.dict', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conv', full_name='CRIU_Opts.conv', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=157,
)

DESCRIPTOR.message_types_by_name['CRIU_Opts'] = _CRIU_OPTS
DESCRIPTOR.extensions_by_name['criu'] = criu
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CRIU_Opts = _reflection.GeneratedProtocolMessageType('CRIU_Opts', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_OPTS,
  __module__ = 'opts_pb2'
  # @@protoc_insertion_point(class_scope:CRIU_Opts)
  ))
_sym_db.RegisterMessage(CRIU_Opts)

criu.message_type = _CRIU_OPTS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(criu)

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tty.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tty.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ttty.proto\x1a\nopts.proto\x1a\nfown.proto\"U\n\rwinsize_entry\x12\x0e\n\x06ws_row\x18\x01 \x02(\r\x12\x0e\n\x06ws_col\x18\x02 \x02(\r\x12\x11\n\tws_xpixel\x18\x03 \x02(\r\x12\x11\n\tws_ypixel\x18\x04 \x02(\r\"\x95\x01\n\rtermios_entry\x12\x0f\n\x07\x63_iflag\x18\x01 \x02(\r\x12\x0f\n\x07\x63_oflag\x18\x02 \x02(\r\x12\x0f\n\x07\x63_cflag\x18\x03 \x02(\r\x12\x0f\n\x07\x63_lflag\x18\x04 \x02(\r\x12\x0e\n\x06\x63_line\x18\x05 \x02(\r\x12\x10\n\x08\x63_ispeed\x18\x06 \x02(\r\x12\x10\n\x08\x63_ospeed\x18\x07 \x02(\r\x12\x0c\n\x04\x63_cc\x18\x08 \x03(\r\"\x1e\n\rtty_pty_entry\x12\r\n\x05index\x18\x01 \x02(\r\".\n\x0etty_data_entry\x12\x0e\n\x06tty_id\x18\x01 \x02(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x02(\x0c\"\xc3\x02\n\x0etty_info_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x16\n\x04type\x18\x02 \x02(\x0e\x32\x08.TtyType\x12\x0e\n\x06locked\x18\x03 \x02(\x08\x12\x11\n\texclusive\x18\x04 \x02(\x08\x12\x13\n\x0bpacket_mode\x18\x05 \x02(\x08\x12\x0b\n\x03sid\x18\x06 \x02(\r\x12\x0c\n\x04pgrp\x18\x07 \x02(\r\x12\x0c\n\x04rdev\x18\x08 \x02(\r\x12\x1f\n\x07termios\x18\t \x01(\x0b\x32\x0e.termios_entry\x12&\n\x0etermios_locked\x18\n \x01(\x0b\x32\x0e.termios_entry\x12\x1f\n\x07winsize\x18\x0b \x01(\x0b\x32\x0e.winsize_entry\x12\x1b\n\x03pty\x18\x0c \x01(\x0b\x32\x0e.tty_pty_entry\x12\x0b\n\x03\x64\x65v\x18\r \x01(\r\x12\x0b\n\x03uid\x18\x0e \x01(\r\x12\x0b\n\x03gid\x18\x0f \x01(\r\"s\n\x0etty_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x13\n\x0btty_info_id\x18\x02 \x02(\r\x12\x14\n\x05\x66lags\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x04 \x02(\x0b\x32\x0b.fown_entry\x12\x0f\n\x07regf_id\x18\x06 \x01(\r*W\n\x07TtyType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03PTY\x10\x01\x12\x0b\n\x07\x43ONSOLE\x10\x02\x12\x06\n\x02VT\x10\x03\x12\x08\n\x04\x43TTY\x10\x04\x12\x0b\n\x07\x45XT_TTY\x10\x05\x12\n\n\x06SERIAL\x10\x06')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,])

_TTYTYPE = _descriptor.EnumDescriptor(
  name='TtyType',
  full_name='TtyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSOLE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CTTY', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXT_TTY', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERIAL', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=799,
  serialized_end=886,
)
_sym_db.RegisterEnumDescriptor(_TTYTYPE)

TtyType = enum_type_wrapper.EnumTypeWrapper(_TTYTYPE)
UNKNOWN = 0
PTY = 1
CONSOLE = 2
VT = 3
CTTY = 4
EXT_TTY = 5
SERIAL = 6



_WINSIZE_ENTRY = _descriptor.Descriptor(
  name='winsize_entry',
  full_name='winsize_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ws_row', full_name='winsize_entry.ws_row', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ws_col', full_name='winsize_entry.ws_col', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ws_xpixel', full_name='winsize_entry.ws_xpixel', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ws_ypixel', full_name='winsize_entry.ws_ypixel', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=122,
)


_TERMIOS_ENTRY = _descriptor.Descriptor(
  name='termios_entry',
  full_name='termios_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='c_iflag', full_name='termios_entry.c_iflag', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_oflag', full_name='termios_entry.c_oflag', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_cflag', full_name='termios_entry.c_cflag', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_lflag', full_name='termios_entry.c_lflag', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_line', full_name='termios_entry.c_line', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_ispeed', full_name='termios_entry.c_ispeed', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_ospeed', full_name='termios_entry.c_ospeed', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_cc', full_name='termios_entry.c_cc', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=274,
)


_TTY_PTY_ENTRY = _descriptor.Descriptor(
  name='tty_pty_entry',
  full_name='tty_pty_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='tty_pty_entry.index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=306,
)


_TTY_DATA_ENTRY = _descriptor.Descriptor(
  name='tty_data_entry',
  full_name='tty_data_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tty_id', full_name='tty_data_entry.tty_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='tty_data_entry.data', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=354,
)


_TTY_INFO_ENTRY = _descriptor.Descriptor(
  name='tty_info_entry',
  full_name='tty_info_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tty_info_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='tty_info_entry.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locked', full_name='tty_info_entry.locked', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exclusive', full_name='tty_info_entry.exclusive', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet_mode', full_name='tty_info_entry.packet_mode', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sid', full_name='tty_info_entry.sid', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pgrp', full_name='tty_info_entry.pgrp', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rdev', full_name='tty_info_entry.rdev', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='termios', full_name='tty_info_entry.termios', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='termios_locked', full_name='tty_info_entry.termios_locked', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='winsize', full_name='tty_info_entry.winsize', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pty', full_name='tty_info_entry.pty', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dev', full_name='tty_info_entry.dev', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='tty_info_entry.uid', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='tty_info_entry.gid', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=680,
)


_TTY_FILE_ENTRY = _descriptor.Descriptor(
  name='tty_file_entry',
  full_name='tty_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tty_file_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tty_info_id', full_name='tty_file_entry.tty_info_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='tty_file_entry.flags', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='tty_file_entry.fown', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regf_id', full_name='tty_file_entry.regf_id', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=797,
)

_TTY_INFO_ENTRY.fields_by_name['type'].enum_type = _TTYTYPE
_TTY_INFO_ENTRY.fields_by_name['termios'].message_type = _TERMIOS_ENTRY
_TTY_INFO_ENTRY.fields_by_name['termios_locked'].message_type = _TERMIOS_ENTRY
_TTY_INFO_ENTRY.fields_by_name['winsize'].message_type = _WINSIZE_ENTRY
_TTY_INFO_ENTRY.fields_by_name['pty'].message_type = _TTY_PTY_ENTRY
_TTY_FILE_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
DESCRIPTOR.message_types_by_name['winsize_entry'] = _WINSIZE_ENTRY
DESCRIPTOR.message_types_by_name['termios_entry'] = _TERMIOS_ENTRY
DESCRIPTOR.message_types_by_name['tty_pty_entry'] = _TTY_PTY_ENTRY
DESCRIPTOR.message_types_by_name['tty_data_entry'] = _TTY_DATA_ENTRY
DESCRIPTOR.message_types_by_name['tty_info_entry'] = _TTY_INFO_ENTRY
DESCRIPTOR.message_types_by_name['tty_file_entry'] = _TTY_FILE_ENTRY
DESCRIPTOR.enum_types_by_name['TtyType'] = _TTYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

winsize_entry = _reflection.GeneratedProtocolMessageType('winsize_entry', (_message.Message,), dict(
  DESCRIPTOR = _WINSIZE_ENTRY,
  __module__ = 'tty_pb2'
  # @@protoc_insertion_point(class_scope:winsize_entry)
  ))
_sym_db.RegisterMessage(winsize_entry)

termios_entry = _reflection.GeneratedProtocolMessageType('termios_entry', (_message.Message,), dict(
  DESCRIPTOR = _TERMIOS_ENTRY,
  __module__ = 'tty_pb2'
  # @@protoc_insertion_point(class_scope:termios_entry)
  ))
_sym_db.RegisterMessage(termios_entry)

tty_pty_entry = _reflection.GeneratedProtocolMessageType('tty_pty_entry', (_message.Message,), dict(
  DESCRIPTOR = _TTY_PTY_ENTRY,
  __module__ = 'tty_pb2'
  # @@protoc_insertion_point(class_scope:tty_pty_entry)
  ))
_sym_db.RegisterMessage(tty_pty_entry)

tty_data_entry = _reflection.GeneratedProtocolMessageType('tty_data_entry', (_message.Message,), dict(
  DESCRIPTOR = _TTY_DATA_ENTRY,
  __module__ = 'tty_pb2'
  # @@protoc_insertion_point(class_scope:tty_data_entry)
  ))
_sym_db.RegisterMessage(tty_data_entry)

tty_info_entry = _reflection.GeneratedProtocolMessageType('tty_info_entry', (_message.Message,), dict(
  DESCRIPTOR = _TTY_INFO_ENTRY,
  __module__ = 'tty_pb2'
  # @@protoc_insertion_point(class_scope:tty_info_entry)
  ))
_sym_db.RegisterMessage(tty_info_entry)

tty_file_entry = _reflection.GeneratedProtocolMessageType('tty_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _TTY_FILE_ENTRY,
  __module__ = 'tty_pb2'
  # @@protoc_insertion_point(class_scope:tty_file_entry)
  ))
_sym_db.RegisterMessage(tty_file_entry)


_TTY_FILE_ENTRY.fields_by_name['flags'].has_options = True
_TTY_FILE_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-unix.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-unix.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rsk-unix.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\":\n\x10\x66ile_perms_entry\x12\x0c\n\x04mode\x18\x01 \x02(\r\x12\x0b\n\x03uid\x18\x02 \x02(\r\x12\x0b\n\x03gid\x18\x03 \x02(\r\"\x95\x03\n\runix_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x15\n\x04type\x18\x03 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05state\x18\x04 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x14\n\x05\x66lags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x15\n\x06uflags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x62\x61\x63klog\x18\x07 \x02(\r\x12\x0c\n\x04peer\x18\x08 \x02(\r\x12\x19\n\x04\x66own\x18\t \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\n \x02(\x0b\x32\x0e.sk_opts_entry\x12\x1c\n\x04name\x18\x0b \x02(\x0c\x42\x0e\xd2?\x0b:\tunix_name\x12\x1e\n\x08shutdown\x18\x0c \x01(\x0e\x32\x0c.sk_shutdown\x12%\n\nfile_perms\x18\r \x01(\x0b\x32\x11.file_perms_entry\x12\x10\n\x08name_dir\x18\x0e \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x0f \x01(\x08\x12\r\n\x05ns_id\x18\x10 \x01(\r\x12\x12\n\x06mnt_id\x18\x11 \x01(\x11:\x02-1\x12\x0c\n\x04stub\x18\x12 \x01(\t')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,sk__opts__pb2.DESCRIPTOR,])




_FILE_PERMS_ENTRY = _descriptor.Descriptor(
  name='file_perms_entry',
  full_name='file_perms_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='file_perms_entry.mode', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='file_perms_entry.uid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='file_perms_entry.gid', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=114,
)


_UNIX_SK_ENTRY = _descriptor.Descriptor(
  name='unix_sk_entry',
  full_name='unix_sk_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='unix_sk_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ino', full_name='unix_sk_entry.ino', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='unix_sk_entry.type', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='unix_sk_entry.state', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='unix_sk_entry.flags', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uflags', full_name='unix_sk_entry.uflags', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backlog', full_name='unix_sk_entry.backlog', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='unix_sk_entry.peer', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='unix_sk_entry.fown', index=8,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='unix_sk_entry.opts', index=9,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='unix_sk_entry.name', index=10,
      number=11, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\013:\tunix_name')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutdown', full_name='unix_sk_entry.shutdown', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_perms', full_name='unix_sk_entry.file_perms', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_dir', full_name='unix_sk_entry.name_dir', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='unix_sk_entry.deleted', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='unix_sk_entry.ns_id', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mnt_id', full_name='unix_sk_entry.mnt_id', index=16,
      number=17, type=17, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stub', full_name='unix_sk_entry.stub', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=522,
)

_UNIX_SK_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_UNIX_SK_ENTRY.fields_by_name['opts'].message_type = sk__opts__pb2._SK_OPTS_ENTRY
_UNIX_SK_ENTRY.fields_by_name['shutdown'].enum_type = sk__opts__pb2._SK_SHUTDOWN
_UNIX_SK_ENTRY.fields_by_name['file_perms'].message_type = _FILE_PERMS_ENTRY
DESCRIPTOR.message_types_by_name['file_perms_entry'] = _FILE_PERMS_ENTRY
DESCRIPTOR.message_types_by_name['unix_sk_entry'] = _UNIX_SK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

file_perms_entry = _reflection.GeneratedProtocolMessageType('file_perms_entry', (_message.Message,), dict(
  DESCRIPTOR = _FILE_PERMS_ENTRY,
  __module__ = 'sk_unix_pb2'
  # @@protoc_insertion_point(class_scope:file_perms_entry)
  ))
_sym_db.RegisterMessage(file_perms_entry)

unix_sk_entry = _reflection.GeneratedProtocolMessageType('unix_sk_entry', (_message.Message,), dict(
  DESCRIPTOR = _UNIX_SK_ENTRY,
  __module__ = 'sk_unix_pb2'
  # @@protoc_insertion_point(class_scope:unix_sk_entry)
  ))
_sym_db.RegisterMessage(unix_sk_entry)


_UNIX_SK_ENTRY.fields_by_name['type'].has_options = True
_UNIX_SK_ENTRY.fields_by_name['type']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk'))
_UNIX_SK_ENTRY.fields_by_name['state'].has_options = True
_UNIX_SK_ENTRY.fields_by_name['state']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0042\002sk'))
_UNIX_SK_ENTRY.fields_by_name['flags'].has_options = True
_UNIX_SK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_UNIX_SK_ENTRY.fields_by_name['uflags'].has_options = True
_UNIX_SK_ENTRY.fields_by_name['uflags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_UNIX_SK_ENTRY.fields_by_name['name'].has_options = True
_UNIX_SK_ENTRY.fields_by_name['name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\013:\tunix_name'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fown.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fown.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\nfown.proto\"V\n\nfown_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0c\n\x04\x65uid\x18\x02 \x02(\r\x12\x0e\n\x06signum\x18\x03 \x02(\r\x12\x10\n\x08pid_type\x18\x04 \x02(\r\x12\x0b\n\x03pid\x18\x05 \x02(\r')
)




_FOWN_ENTRY = _descriptor.Descriptor(
  name='fown_entry',
  full_name='fown_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='fown_entry.uid', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='euid', full_name='fown_entry.euid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signum', full_name='fown_entry.signum', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid_type', full_name='fown_entry.pid_type', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='fown_entry.pid', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14,
  serialized_end=100,
)

DESCRIPTOR.message_types_by_name['fown_entry'] = _FOWN_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

fown_entry = _reflection.GeneratedProtocolMessageType('fown_entry', (_message.Message,), dict(
  DESCRIPTOR = _FOWN_ENTRY,
  __module__ = 'fown_pb2'
  # @@protoc_insertion_point(class_scope:fown_entry)
  ))
_sym_db.RegisterMessage(fown_entry)


# @@protoc_insertion_point(module_scope)
